<?php

namespace Drupal\performance_budget\EventSubscriber;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\performance_budget\Event\AggregateJobCompleteEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscribes to the web page archive events.
 */
class WebPageTestEventSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   *
   * @return array
   *   The event names to listen for, and the methods that should be executed.
   */
  public static function getSubscribedEvents() {
    return [
      AggregateJobCompleteEvent::EVENT_NAME => 'aggregateJobComplete',
    ];
  }

  /**
   * React to a capture job completing.
   *
   * @param \Drupal\performance_budget\Event\AggregateJobCompleteEvent $event
   *   Capture job completion event.
   */
  public function aggregateJobComplete(AggregateJobCompleteEvent $event) {
    \Drupal::messenger()->addStatus($this->t('Data aggregation complete for @name job.', ['@name' => $event->webPageArchive->label()]));
  }

}
